%define ALD_Ver		2.0

%define OrgName libjpeg-turbo

Name:         libjpeg

License:      IJG BSD zlib
Summary:      A SIMD-accelerated JPEG codec that provides both the libjpeg and TurboJPEG APIs
Version:      1.5.4
Release:      0
URL: http://www.libjpeg-turbo.org

Source: %{OrgName}-%{version}.tar.xz

%define DestDir		/graphics
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
libjpeg-turbo is a derivative of libjpeg that uses SIMD instructions (MMX,
SSE2, NEON) to accelerate baseline JPEG compression and decompression on x86,
x86-64, and ARM systems.  On such systems, libjpeg-turbo is generally 2-4x as
fast as the unmodified version of libjpeg, all else being equal.
# --------------------------------------
%package tools
Summary:      jpeg tools cjpeg,djpeg,jpegtran,...
Requires:     %{name} = %{version}
%description tools
jpeg tools cjpeg,djpeg,jpegtran,...
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Requires:     %{name} = %{version}
%description devel
These libraries are needed to compile C code.
# --------------------------------------
%package turbo
Summary:      Libraries libturbojpeg.so.xx
%description turbo
libturbojpeg.so.xx
# --------------------------------------
%package turbo-devel
Summary:      Libraries for the C compiler libturbojpeg .so .h
Requires:     %{name} = %{version}
Requires:     %{name}-devel
%description turbo-devel
These libraries are needed to compile C code.
# --------------------------------------
%package staticlib
Summary:      %{name} static Libraries
Requires:     %{name} = %{version}
%description staticlib
%{name} static Libraries
# --------------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package CROSS
Summary:      %{name} Cross-%{_target_cpu}
%description CROSS
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

autoreconf -fiv

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -ffast-math -falign-functions=4 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -ffast-math"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -ffast-math -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
export INSTALL="/usr/bin/install -p -c"

%configure  \
	--enable-static \
%if %{_os} == "mingw"
	--disable-shared \
%else
	--enable-shared \
%endif
	--disable-libtool-lock \
	&>Fconfigure_log.txt

make V=1 &>Fmake_log.txt

# ------------------- Install ----------------------------------------
%Install

%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

rm -rf $RPM_BUILD_ROOT%{_defaultdocdir}/libjpeg-turbo
cp -p LICENSE.md README.md README.ijg example.c libjpeg.txt usage.txt wizard.txt $RPM_BUILD_ROOT%{docdir}/

%if %{_arch} == "x86_64"
  mv $RPM_BUILD_ROOT%{_includedir}/jconfig.h $RPM_BUILD_ROOT%{_includedir}/jconfig-64.h
cat > $RPM_BUILD_ROOT%{_includedir}/jconfig.h <<EOF
#if !defined __x86_64__
# include <jconfig-32.h>
#endif
#if defined __x86_64__ && defined __LP64__
# include <jconfig-64.h>
#endif
#if defined __x86_64__ && defined __ILP32__
# include <jconfig-x32.h>
#endif
EOF
%endif

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------

%files
%{_libdir}/libjpeg.so.*
%dir %{docdir}
%{docdir}/LICENSE.md
%{docdir}/README.md

%files tools
%{_bindir}
%{_mandir}

%files devel
%{_includedir}/j*
%{_libdir}/libjpeg.so
%{_libdir}/pkgconfig/libjpeg.pc

%files turbo
%{_libdir}/libturbojpeg.so.*

%files turbo-devel
%{_includedir}/turbojpeg.h
%{_libdir}/libturbojpeg.so
%{_libdir}/pkgconfig/libturbojpeg.pc

%Files staticlib
%{_libdir}/libjpeg.a
%{_libdir}/libturbojpeg.a

%files doc
%{docdir}/README.ijg
%{docdir}/example.c
%{docdir}/*.txt

# ------------------- Cross Files ------------------------------------
%if %{MakeLocCross} && %{have_auto_local}

%files CROSS
%{CrossPath}%{_includedir}
%{CrossPath}%{_libdir}/*.so.*
%{CrossPath}%{_libdir}/*.so
%{CrossPath}%{_libdir}/libjpeg.a
%{CrossPath}%{_libdir}/libturbojpeg.a
%{CrossPath}%{_libdir}/pkgconfig
%{CrossPath}%{docdir}

%endif # MakeLocCross
